diff --git a/NEWS b/NEWS
index 8ba35e5b31..d624c2a799 100644
--- a/NEWS
+++ b/NEWS
@@ -8756,7 +8756,7 @@ CHANGES WITH 236:
* The watchdog device PID 1 will ping may now be configured through the
WatchdogDevice= configuration file setting, or by setting the
- systemd.watchdog_service= kernel commandline option.
+ systemd.watchdog_service= kernel command line option.
* systemd-resolved's gained support for registering DNS-SD services on
the local network using MulticastDNS. Services may either be
diff --git a/man/hostname.xml b/man/hostname.xml
index d050703792..a3dae72fd9 100644
--- a/man/hostname.xml
+++ b/man/hostname.xml
@@ -56,7 +56,7 @@
systemd1 and the
associated tools will obtain the hostname in the following ways:
- If the kernel commandline parameter systemd.hostname= specifies a
+ If the kernel command line parameter systemd.hostname= specifies a
valid hostname,
systemd1 will use it
to set the hostname during early boot, see
diff --git a/man/systemctl.xml b/man/systemctl.xml
index 22aebfbafe..1a424c1e2b 100644
--- a/man/systemctl.xml
+++ b/man/systemctl.xml
@@ -1643,7 +1643,7 @@ Jan 12 10:46:45 example.com bluetoothd[8900]: gatt-time-server: Input/output err
Shut down and reboot the system via kexec. This command will load a
kexec kernel if one wasn't loaded yet or fail. A kernel may be loaded earlier by a separate step,
- this is particularly useful if a custom initrd or additional kernel commandline options are
+ this is particularly useful if a custom initrd or additional kernel command line options are
desired. The can be used to continue without a kexec kernel, i.e. to
perform a normal reboot. The final reboot step is equivalent to
systemctl start kexec.target --job-mode=replace-irreversibly --no-block.
diff --git a/man/systemd-coredump.xml b/man/systemd-coredump.xml
index 14fd217429..0c1efabcc1 100644
--- a/man/systemd-coredump.xml
+++ b/man/systemd-coredump.xml
@@ -354,7 +354,7 @@ flags: ...
COREDUMP_CONTAINER_CMDLINE=
- For processes running in a container, the commandline of the process spawning the
+ For processes running in a container, the command line of the process spawning the
container (the first parent process with a different mount namespace).
diff --git a/man/ukify.xml b/man/ukify.xml
index 0d8a227796..f6cd6804bb 100644
--- a/man/ukify.xml
+++ b/man/ukify.xml
@@ -170,7 +170,7 @@
The following options and settings are understood:
- Commandline-only options
+ Command line-only options
@@ -178,7 +178,7 @@
Load configuration from the given config file. In general, settings specified in
the config file have lower precedence than the settings specified via options. In cases where the
- commandline option does not fully override the config file setting are explicitly mentioned in the
+ command line option does not fully override the config file setting are explicitly mentioned in the
descriptions of individual options.
@@ -243,7 +243,7 @@
Print a summary of loaded config and exit. This is useful to check how the options
- form the configuration file and the commandline are combined.
+ form the configuration file and the command line are combined.
@@ -489,7 +489,7 @@
[PCRSignature:NAME] section
- In the config file, those options are grouped by section. On the commandline, they
+ In the config file, those options are grouped by section. On the command line, they
must be specified in the same order. The sections specified in both sources are combined.
@@ -498,7 +498,7 @@
PCRPrivateKey=PATH
- A private key to use for signing PCR policies. On the commandline, this option may
+ A private key to use for signing PCR policies. On the command line, this option may
be specified more than once, in which case multiple signatures will be made.
@@ -510,9 +510,9 @@
A public key to use for signing PCR policies.
- On the commandline, this option may be specified more than once, similarly to the
+ On the command line, this option may be specified more than once, similarly to the
option. If not present, the public keys will be extracted from
- the private keys. On the commandline, if present, the this option must be specified the same number
+ the private keys. On the command line, if present, the this option must be specified the same number
of times as the option.
@@ -528,7 +528,7 @@
systemd-measure1
will be used.
- On the commandline, when this argument is present, it must appear the same number of times as
+ On the command line, when this argument is present, it must appear the same number of times as
the option.
@@ -621,7 +621,7 @@ $ ukify -c ukify.conf build \
One "initrd" (early_cpio) is specified in the config file, and
the other initrd (initramfs-6.0.9-300.fc37.x86_64.img) is specified
- on the commandline. This may be useful for example when the first initrd contains microcode for the CPU
+ on the command line. This may be useful for example when the first initrd contains microcode for the CPU
and does not need to be updated when the kernel version changes, unlike the actual initrd.
diff --git a/src/basic/log.c b/src/basic/log.c
index a41d4bcdb6..7181f3a2ad 100644
--- a/src/basic/log.c
+++ b/src/basic/log.c
@@ -1276,7 +1276,7 @@ static bool should_parse_proc_cmdline(void) {
if (getpid_cached() == 1)
return true;
- /* Otherwise, parse the commandline if invoked directly by systemd. */
+ /* Otherwise, parse the command line if invoked directly by systemd. */
return invoked_by_systemd();
}
diff --git a/src/basic/process-util.c b/src/basic/process-util.c
index ea3456f6b8..4928379bd7 100644
--- a/src/basic/process-util.c
+++ b/src/basic/process-util.c
@@ -198,7 +198,7 @@ int get_process_cmdline(pid_t pid, size_t max_columns, ProcessCmdlineFlags flags
assert(pid >= 0);
assert(ret);
- /* Retrieve and format a commandline. See above for discussion of retrieval options.
+ /* Retrieve and format a command line. See above for discussion of retrieval options.
*
* There are two main formatting modes:
*
diff --git a/src/shared/install.c b/src/shared/install.c
index c171a2330e..e25e78629e 100644
--- a/src/shared/install.c
+++ b/src/shared/install.c
@@ -2334,7 +2334,7 @@ int unit_file_unmask(
if (!unit_name_is_valid(*name, UNIT_NAME_ANY))
return -EINVAL;
- /* If root_dir is set, we don't care about kernel commandline or generators.
+ /* If root_dir is set, we don't care about kernel command line or generators.
* But if it is not set, we need to check for interference. */
if (!root_dir) {
_cleanup_(install_info_clear) InstallInfo info = {
diff --git a/src/core/main.c b/src/core/main.c
index 21582ddd0c..6f779586d0 100644
--- a/src/core/main.c
+++ b/src/core/main.c
@@ -780,7 +780,7 @@ static void set_manager_settings(Manager *m) {
if (r < 0)
log_warning_errno(r, "Failed to set watchdog pretimeout governor to '%s', ignoring: %m", arg_watchdog_pretimeout_governor);
- manager_set_show_status(m, arg_show_status, "commandline");
+ manager_set_show_status(m, arg_show_status, "command line");
m->status_unit_format = arg_status_unit_format;
}
@@ -2130,15 +2130,15 @@ static void log_execution_mode(bool *ret_first_boot) {
_cleanup_free_ char *id_text = NULL;
/* Let's check whether we are in first boot. First, check if an override was
* specified on the kernel commandline. If yes, we honour that. */
r = proc_cmdline_get_bool("systemd.condition-first-boot", /* flags = */ 0, &first_boot);
if (r < 0)
- log_debug_errno(r, "Failed to parse systemd.condition-first-boot= kernel commandline argument, ignoring: %m");
+ log_debug_errno(r, "Failed to parse systemd.condition-first-boot= kernel command line argument, ignoring: %m");
if (r > 0)
log_full(first_boot ? LOG_INFO : LOG_DEBUG,
- "Kernel commandline argument says we are %s first boot.",
+ "Kernel command line argument says we are %s first boot.",
first_boot ? "in" : "not in");
else {
/* Second, perform autodetection. We use /etc/machine-id as flag file for
@@ -2991,7 +2991,7 @@ int main(int argc, char *argv[]) {
r = parse_argv(argc, argv);
if (r < 0) {
- error_message = "Failed to parse commandline arguments";
+ error_message = "Failed to parse command line arguments";
goto finish;
}
@@ -2130,15 +2130,15 @@ static void log_execution_mode(bool *ret_first_boot) {
_cleanup_free_ char *id_text = NULL;
/* Let's check whether we are in first boot. First, check if an override was
- * specified on the kernel commandline. If yes, we honour that. */
+ * specified on the kernel command line. If yes, we honour that. */
r = proc_cmdline_get_bool("systemd.condition-first-boot", /* flags = */ 0, &first_boot);
if (r < 0)
diff --git a/src/systemctl/systemctl-set-default.c b/src/systemctl/systemctl-set-default.c
index 136a4f3b66..58c2bc335d 100644
--- a/src/systemctl/systemctl-set-default.c
+++ b/src/systemctl/systemctl-set-default.c
@@ -31,7 +31,7 @@ static int parse_proc_cmdline_item(const char *key, const char *value, void *dat
static void emit_cmdline_warning(void) {
if (arg_quiet || arg_root)
/* don't bother checking the commandline if we're operating on a container */
return;
_cleanup_free_ char *override = NULL;
@@ -41,7 +41,7 @@ static void emit_cmdline_warning(void) {
if (r < 0)
log_debug_errno(r, "Failed to parse kernel command line, ignoring: %m");
if (override)
- log_notice("Note: found \"%s\" on the kernel commandline, which overrides the default unit.",
+ log_notice("Note: found \"%s\" on the kernel command line, which overrides the default unit.",
override);
}
@@ -31,7 +31,7 @@ static int parse_proc_cmdline_item(const char *key, const char *value, void *dat
static void emit_cmdline_warning(void) {
if (arg_quiet || arg_root)
- /* don't bother checking the commandline if we're operating on a container */
+ /* don't bother checking the command line if we're operating on a container */
return;
_cleanup_free_ char *override = NULL;
diff --git a/src/ukify/ukify.py b/src/ukify/ukify.py
index 890a694e68..432dc87988 100755
--- a/src/ukify/ukify.py
+++ b/src/ukify/ukify.py
@@ -1523,7 +1523,7 @@ def finalize_options(opts):
elif opts.linux or opts.initrd:
raise ValueError('--linux/--initrd options cannot be used with positional arguments')
else:
- print("Assuming obsolete commandline syntax with no verb. Please use 'build'.")
+ print("Assuming obsolete command line syntax with no verb. Please use 'build'.")
if opts.positional:
opts.linux = pathlib.Path(opts.positional[0])
# If we have initrds from parsing config files, append our positional args at the end
@@ -1543,8 +1543,8 @@ def finalize_options(opts):
if opts.cmdline and opts.cmdline.startswith('@'):
opts.cmdline = pathlib.Path(opts.cmdline[1:])
elif opts.cmdline:
# Drop whitespace from the commandline. If we're reading from a file,
# we copy the contents verbatim. But configuration specified on the commandline
# or in the config file may contain additional whitespace that has no meaning.
opts.cmdline = ' '.join(opts.cmdline.split())
@@ -1543,8 +1543,8 @@ def finalize_options(opts):
opts.cmdline = pathlib.Path(opts.cmdline[1:])
elif opts.cmdline:
- # Drop whitespace from the commandline. If we're reading from a file,
- # we copy the contents verbatim. But configuration specified on the commandline
+ # Drop whitespace from the command line. If we're reading from a file,
+ # we copy the contents verbatim. But configuration specified on the command line
# or in the config file may contain additional whitespace that has no meaning.
opts.cmdline = ' '.join(opts.cmdline.split())